@@ -229,7 +229,7 @@ class DatetimeMixin(Model):
     )
 
 
-class Model(DatetimeMixin, Model):
+class Model(DatetimeMixin, django.db.models.Model):
     """
     优化的模型基类，默认包括入库时间和更新时间字段，并自动将复数名称重定义到单数名称。
 
